// content.js
class PostAnalyzer {
  constructor(minLikes = 100) {
    this.minLikes = minLikes;
    this.posts = [];
    this.isScrolling = false;
  }

  // Convertit le texte des likes en nombre
  parseLikeCount(text) {
    if (!text) return 0;
    const number = text.match(/\d+/g)?.join('');
    if (text.includes('K')) {
      return parseInt(number) * 1000;
    }
    return parseInt(number) || 0;
  }

  // Extrait les données d'un post
  async extractPostData(post) {
    const likeElement = post.querySelector('[aria-label*="réactions"]');
    const likeCount = this.parseLikeCount(likeElement?.getAttribute('aria-label'));
    
    if (likeCount >= this.minLikes) {
      const pageLink = post.querySelector('a[href*="/pages/"]') || 
                      post.querySelector('a[href*="/profile/"]');
      
      if (pageLink) {
        return {
          pageName: pageLink.textContent,
          pageUrl: pageLink.href,
          likes: likeCount,
          postUrl: post.querySelector('a[href*="/posts/"]')?.href,
          timestamp: post.querySelector('a[href*="/posts/"]')?.textContent
        };
      }
    }
    return null;
  }

  // Scroll automatique
  async autoScroll() {
    this.isScrolling = true;
    
    while (this.isScrolling) {
      window.scrollTo(0, document.body.scrollHeight);
      const posts = document.querySelectorAll('[role="article"]');
      
      for (const post of posts) {
        if (!post.dataset.analyzed) {
          const data = await this.extractPostData(post);
          if (data) {
            this.posts.push(data);
          }
          post.dataset.analyzed = 'true';
        }
      }

      await new Promise(resolve => setTimeout(resolve, 2000));
    }
  }

  // Arrête le scroll
  stopScrolling() {
    this.isScrolling = false;
  }

  // Exporte en CSV
  exportToCsv() {
    const headers = ['Page Name', 'Page URL', 'Likes', 'Post URL', 'Timestamp'];
    const rows = [headers];
    
    this.posts.forEach(post => {
      rows.push([
        post.pageName,
        post.pageUrl,
        post.likes,
        post.postUrl,
        post.timestamp
      ]);
    });

    const csvContent = rows.map(row => row.join(',')).join('\n');
    const blob = new Blob([csvContent], { type: 'text/csv' });
    const url = URL.createObjectURL(blob);
    
    const a = document.createElement('a');
    a.href = url;
    a.download = 'post_analysis.csv';
    a.click();
  }
}

// Initialisation et contrôles
const analyzer = new PostAnalyzer(100);

// Ajoute un bouton de contrôle
const controls = document.createElement('div');
controls.style.cssText = `
  position: fixed;
  bottom: 20px;
  right: 20px;
  z-index: 9999;
  background: white;
  padding: 10px;
  border-radius: 5px;
  box-shadow: 0 2px 5px rgba(0,0,0,0.2);
`;

const startButton = document.createElement('button');
startButton.textContent = 'Démarrer Analyse';
startButton.onclick = () => analyzer.autoScroll();

const stopButton = document.createElement('button');
stopButton.textContent = 'Arrêter';
stopButton.onclick = () => analyzer.stopScrolling();

const exportButton = document.createElement('button');
exportButton.textContent = 'Exporter CSV';
exportButton.onclick = () => analyzer.exportToCsv();

controls.append(startButton, stopButton, exportButton);
document.body.appendChild(controls);